Hello
======

A simple hello world utility for use with Python Packaging Training


Installation
------------

This is how you install Hello


Usage
------

Use hello to print Hello World or the user name to the terminal
